<a name="aea.helpers.exception_policy"></a>
# aea.helpers.exception`_`policy

This module contains enum of aea exception policies.

<a name="aea.helpers.exception_policy.ExceptionPolicyEnum"></a>
## ExceptionPolicyEnum Objects

```python
class ExceptionPolicyEnum(Enum)
```

AEA Exception policies.

